==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/General/fileops/translations/fileops_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <source>Error</source>
        <translation>事故</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="99"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>移動先ディレクトリが存在しません</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="104"/>
        <source>Copying</source>
        <translation>コピーしています</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="105"/>
        <source>Stop</source>
        <translation>中止</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="146"/>
        <source>Copying file %1/%2</source>
        <translation>%1/%2 ファイルをコピーしています</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="189"/>
        <source>Remove files</source>
        <translation>ファイルを削除</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="190"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>%n 個のファイルをディスク上から削除しようとしています。 よろしいですか？</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>ファイル操作プラグイン</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>ファイル操作プラグインについて</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>QMMP ファイル操作プラグイン</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>ショートカットの変更</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>割り当てたいキーの組み合わせを押します</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>消去</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>ファイル操作設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>有効</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>操作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>メニューの文言</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="55"/>
        <location filename="../settingsdialog.cpp" line="135"/>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>目的地:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>ファイル名の様式:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Rename</source>
        <translation>名称変更</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="138"/>
        <source>New action</source>
        <translation>新しい動作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="192"/>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="193"/>
        <source>Album</source>
        <translation>アルバム</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="194"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Track number</source>
        <translation>トラック番号</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="196"/>
        <source>Two-digit track number</source>
        <translation>トラック番号 数字2桁</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="197"/>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="198"/>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="199"/>
        <source>Composer</source>
        <translation>作曲者</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="200"/>
        <source>Duration</source>
        <translation>演奏時間</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="201"/>
        <source>Disc number</source>
        <translation>ディスク番号</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="202"/>
        <source>File name</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="203"/>
        <source>File path</source>
        <translation>ファイルパス</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="204"/>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="205"/>
        <source>Condition</source>
        <translation>定番</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="221"/>
        <source>Choose a directory</source>
        <translation>ディレクトリを選択</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/General/fileops/translations/fileops_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <location filename="../fileops.cpp" line="132"/>
        <source>Error</source>
        <translation>事故</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="99"/>
        <location filename="../fileops.cpp" line="133"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>収容先ディレクトリが存在しません</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="136"/>
        <source>Move Files</source>
        <translation>ファイル移動</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="137"/>
        <source>Are you sure you want to move %n file(s)?</source>
        <translation>
            <numerusform>%n 個のファイルを移動しようとしています。 よろしいですか?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="153"/>
        <source>Copying</source>
        <translation>コピーしています</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="154"/>
        <location filename="../fileops.cpp" line="244"/>
        <source>Stop</source>
        <translation>中止</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="199"/>
        <source>Copying file %1/%2</source>
        <translation>%1/%2 ファイルをコピーしています</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="243"/>
        <source>Moving</source>
        <translation>移動中</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="276"/>
        <source>Moving file %1/%2</source>
        <translation>%1/%2 ファイルを移動しています</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="114"/>
        <source>Remove Files</source>
        <translation>ファイル削除</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="115"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>%n 個のファイルをディスク上から削除しようとしています。 よろしいですか？</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="31"/>
        <source>File Operations Plugin</source>
        <translation>ファイル操作プラグイン</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>About File Operations Plugin</source>
        <translation>ファイル操作プラグインについて</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>QMMP ファイル操作プラグイン</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>ショートカットの変更</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>割り当てたいキーの組み合わせを押します</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>消去</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>ファイル操作設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>発効</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>操作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>メニューの項目名</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="54"/>
        <location filename="../settingsdialog.cpp" line="134"/>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>ファイル収容先:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>ファイル名の様式:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Rename</source>
        <translation>名称変更</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Move</source>
        <translation>移動</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="137"/>
        <source>New action</source>
        <translation>新しい動作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="220"/>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="221"/>
        <source>Album</source>
        <translation>アルバム</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="222"/>
        <source>Album Artist</source>
        <translation>アルバムアーティスト</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="223"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="224"/>
        <source>Track Number</source>
        <translation>トラック番号</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="225"/>
        <source>Two-digit Track Number</source>
        <translation>トラック番号 数字2桁</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="230"/>
        <source>Disc Number</source>
        <translation>ディスク番号</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="231"/>
        <source>File Name</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="232"/>
        <source>File Path</source>
        <translation>ファイルパス</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="226"/>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="227"/>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="228"/>
        <source>Composer</source>
        <translation>作曲者</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="229"/>
        <source>Duration</source>
        <translation>演奏時間</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="233"/>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="234"/>
        <source>Condition</source>
        <translation>定番</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="247"/>
        <source>Choose a directory</source>
        <translation>ディレクトリを選択</translation>
    </message>
</context>
</TS>
